
XML_NAMESPACE_FLOW_CONTROL = 'https://doculabs.io/2020/xtmpl#control'
XML_NAMESPACE_DATA_BINDING = 'https://doculabs.io/2020/xtmpl#data-binding'
XML_NAMESPACE_NOOP = 'https://doculabs.io/2020/xtmpl#noop'
XML_NAMESPACE_POJO = 'https://doculabs.io/2020/xtmpl#javascript'
XML_TEXT_BINDING_TAG = f'{{{XML_NAMESPACE_DATA_BINDING}}}text'
INDENT = '    '
