<kr-sidebar-header>
  <div class="navbar-nav me-auto mb-2 mb-lg-0">
    <span class="navbar-brand">kirUI</span>
  </div>
  <div class="btn-group">
      <a href="#" b:text="str('Én vagyok')" class="dropdown-toggle" style="color: #fff; text-decoration: none;"></a>
      <ul class="dropdown-menu">
        <li><a href="#" class="dropdown-item"><i class="bi bi-lock-fill"></i> Change Password</a></li>
        <li><a href="#" class="dropdown-item"><i class="bi bi-gear-fill"></i> Admin Setion</a></li>
        <li><a href="#" class="dropdown-item"><i class="bi bi-gear-wide-connected"></i> IMAP Settings</a></li>
        <li>
          <hr class="dropdown-divider" />
        </li>
        <li><a href="#" class="dropdown-item"><i class="bi bi-box-arrow-right"></i> Sign out</a></li>
      </ul>
  </div>
</kr-sidebar-header>