kr-multi-select-checkbox {
  .parent {
    width: 100%;
    display: inline-block;
    position: relative;
    vertical-align: middle;
  }

  .is-invalid {
    .header {
      padding-right: 4.125rem;
      background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23343a40' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='M2 5l6 6 6-6'/%3e%3c/svg%3e"), url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 12 12' width='12' height='12' fill='none' stroke='%23dc3545'%3e%3ccircle cx='6' cy='6' r='4.5'/%3e%3cpath stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/%3e%3ccircle cx='6' cy='8.2' r='.6' fill='%23dc3545' stroke='none'/%3e%3c/svg%3e");
      background-position: right 0.75rem center, center right 2.25rem;
      background-size: 16px 12px, calc(0.75em + 0.375rem) calc(0.75em + 0.375rem);
      border-color: #dc3545;
      background-repeat: no-repeat;
    }
  }

  .header {
    display: flex;
    width: 100%;
    padding: 0.375rem 0.75rem;
    margin: 0;
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.5;
    color: #212529;
    user-select: none;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid #ced4da;
    appearance: none;
    border-radius: 0.25rem;
    transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    padding-right: 4.125rem;
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23343a40' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='M2 5l6 6 6-6'/%3e%3c/svg%3e");
    background-position: right 0.75rem center, center right 2.25rem;
    background-size: 16px 12px, calc(0.75em + 0.375rem);
    background-repeat: no-repeat;

    .select-value {
      flex-grow: 1;
      padding-top: 0.25rem;
      text-overflow: ellipsis;
      overflow: hidden;
      white-space: nowrap;
    }
  }

  .readonly .header {
    background-color: #e9ecef !important;
  }

  .dropdown {
	overflow: hidden;
	display: none;
	padding: 0 0.5rem;
	position: absolute;
	z-index: 1000;
	top: 100%;
	background: #fff;
	color: #000;
	border: 1px solid #aaa;
	border-radius: 0 0 4px 4px;
    width: 100%;

    .row { padding: 0.25rem 0; }
    .row input { margin-right: 0.5rem; }
  }

  .show { display: block !important; }
  .invalid-feedback { display: block; }
}